@@ -6,7 +6,7 @@ use 5.014;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 use Carp qw(confess cluck);
 use DateTime;
@@ -21,10 +21,6 @@ use XML::LibXML;
 sub new {
 	my ( $class, %opt ) = @_;
 
-	my %lwp_options = %{ $opt{lwp_options} // { timeout => 10 } };
-
-	my $ua = LWP::UserAgent->new(%lwp_options);
-
 	if ( not $opt{station} ) {
 		confess('station flag must be passed');
 	}
@@ -35,14 +31,15 @@ sub new {
 		developer_mode => $opt{developer_mode},
 		iris_base      => $opt{iris_base}
 		  // 'http://iris.noncd.db.de/iris-tts/timetable',
-		lookahead => $opt{lookahead} // ( 4 * 60 ),
-		main_cache      => $opt{main_cache},
-		rt_cache        => $opt{realtime_cache},
+		lookahead  => $opt{lookahead}  // ( 3 * 60 ),
+		lookbehind => $opt{lookbehind} // ( 0 * 60 ),
+		main_cache => $opt{main_cache},
+		rt_cache   => $opt{realtime_cache},
 		serializable    => $opt{serializable},
-		user_agent      => $ua,
+		user_agent      => $opt{user_agent},
 		with_related    => $opt{with_related},
 		departure_by_id => {},
-		strptime_obj    => DateTime::Format::Strptime->new(
+		strptime_obj => $opt{strptime_obj} // DateTime::Format::Strptime->new(
 			pattern   => '%y%m%d%H%M',
 			time_zone => 'Europe/Berlin',
 		),
@@ -51,7 +48,11 @@ sub new {
 
 	bless( $self, $class );
 
-	$ua->env_proxy;
+	if ( not $self->{user_agent} ) {
+		my %lwp_options = %{ $opt{lwp_options} // { timeout => 10 } };
+		$self->{user_agent} = LWP::UserAgent->new(%lwp_options);
+		$self->{user_agent}->env_proxy;
+	}
 
 	my ( $station, @related_stations ) = $self->get_station(
 		name      => $opt{station},
@@ -67,9 +68,12 @@ sub new {
 			datetime       => $self->{datetime},
 			developer_mode => $self->{developer_mode},
 			lookahead      => $self->{lookahead},
+			lookbehind     => $self->{lookbehind},
 			station        => $ref->{uic},
 			main_cache     => $self->{main_cache},
 			realtime_cache => $self->{rt_cache},
+			strptime_obj   => $self->{strptime_obj},
+			user_agent     => $self->{user_agent},
 			with_related   => 0,
 		);
 		if ( not $ref_status->errstr ) {
@@ -82,10 +86,15 @@ sub new {
 	}
 
 	my $dt_req = $self->{datetime}->clone;
-	for ( 1 .. 3 ) {
+	for ( 1 .. int( $self->{lookahead} / 60 ) ) {
 		$self->get_timetable( $self->{station}{uic}, $dt_req );
 		$dt_req->add( hours => 1 );
 	}
+	$dt_req = $self->{datetime}->clone;
+	for ( 1 .. int( $self->{lookbehind} / 60 ) ) {
+		$dt_req->subtract( hours => 1 );
+		$self->get_timetable( $self->{station}{uic}, $dt_req );
+	}
 
 	$self->get_realtime;
 
@@ -549,7 +558,7 @@ Travel::Status::DE::IRIS - Interface to IRIS based web departure monitors.
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =head1 DESCRIPTION
 
@@ -581,15 +590,28 @@ IRIS base url, defaults to C<< http://iris.noncd.db.de/iris-tts/timetable >>.
 
 =item B<lookahead> => I<int>
 
-Compute only those results which are less than I<int> minutes in the future.
-Default: 240 (4 hours).
+Compute only results which are less than I<int> minutes in the future.
+Default: 180 (3 hours).
 
-Note that the DeutscheBahn IRIS backend only provides schedules up to four
-to five hours into the future, and this module only requests data for up to
-three hours. So in most cases, setting this to a value above 180 minutes will
-have no effect. However, as the IRIS occasionally contains unscheduled
-departures or qos messages known far in advance (e.g. 12 hours from now), any
-non-negative integer is accepted.
+Note that the DeutscheBahn IRIS backend only provides schedules up to four to
+five hours into the future. So in most cases, setting this to a value above 240
+minutes will have little effect. However, as the IRIS occasionally contains
+unscheduled departures or qos messages known far in advance (e.g. 12 hours from
+now), any non-negative integer is accepted.
+
+=item B<lookbehind> => I<int>
+
+Also check trains whose scheduled departure lies up to I<int> minutes in the
+past. Default: 0.
+
+This is useful when requesting departures shortly after a full hour. If,
+for example, a train was scheduled to depart on 11:59 and has 5 minutes delay,
+it will not be shown when requesting departures on or after 12:00 unless
+B<lookbehind> is set to a value greater than zero.
+
+Note that trains with significant delay (e.g. +30) may still be shown in this
+case regardless of the setting of B<lookbehind>, since these receive special
+treatment by the IRIS backend.
 
 =item B<lwp_options> => I<\%hashref>
 
