@@ -57,6 +57,7 @@ while ( my $line = <STDIN> ) {
 	$name =~ s{\s+}{ }g;
 	$name =~ s{'}{\\'}g;
 
+	$station =~ s{ ^ EBIL     $ }{EBILP}x;
 	$station =~ s{ ^ EBLA     $ }{EBP}x;
 	$station =~ s{ ^ EBTHP    $ }{EBTH}x;
 	$station =~ s{ ^ EDO \s N $ }{EDO}x;
@@ -1891,7 +1892,7 @@ sub get_station_by_location {
 	my @station_map = pairwise { [ $a, $b ] } @candidates, @distances;
 
 	@station_map = sort { $a->[1] <=> $b->[1] } @station_map;
-	splice( @station_map, 10 );
+	splice( @station_map, $num_matches );
 
 	return @station_map;
 }
